@@ -1,8 +1,12 @@
+pub use sys_class::SysClass;
+#[macro_use]
+mod sys_class;
+
 pub use block::Block;
 mod block;
 
+pub use dmi::DmiId;
+mod dmi;
+
 pub use hwmon::{HwMon, HwMonFan, HwMonPwm, HwMonTemp};
 mod hwmon;
-
-pub use sys_class::SysClass;
-mod sys_class;
